==> jc-1.4.0.tar.gz: javax/crypto/spec/DHPrivateKeySpec.h <==
// public class javax.crypto.spec.DHPrivateKeySpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 35635a1ccf7cce67 javax_crypto_spec_DHPrivateKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_DHPrivateKeySpec_H_
#define _JC_javax_crypto_spec_DHPrivateKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_DHPrivateKeySpec$sub_refs	_jc_javax_crypto_spec_DHPrivateKeySpec$sub_refs;
typedef struct _jc_javax_crypto_spec_DHPrivateKeySpec$sub_nonrefs	_jc_javax_crypto_spec_DHPrivateKeySpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_DHPrivateKeySpec$refs	_jc_javax_crypto_spec_DHPrivateKeySpec$refs;
typedef struct _jc_javax_crypto_spec_DHPrivateKeySpec$nonrefs	_jc_javax_crypto_spec_DHPrivateKeySpec$nonrefs;
typedef struct _jc_javax_crypto_spec_DHPrivateKeySpec$object	_jc_javax_crypto_spec_DHPrivateKeySpec$object;

typedef const struct _jc_javax_crypto_spec_DHPrivateKeySpec$vmethods	_jc_javax_crypto_spec_DHPrivateKeySpec$vmethods;
typedef const struct _jc_javax_crypto_spec_DHPrivateKeySpec$vtable	_jc_javax_crypto_spec_DHPrivateKeySpec$vtable;
typedef const struct _jc_javax_crypto_spec_DHPrivateKeySpec$vtype	_jc_javax_crypto_spec_DHPrivateKeySpec$vtype;

// Constructors
extern void _jc_javax_crypto_spec_DHPrivateKeySpec$method$_init$6cf26681d886fcf0(_jc_env *, struct _jc_javax_crypto_spec_DHPrivateKeySpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *);

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_javax_crypto_spec_DHPrivateKeySpec$method$getG$59cffd735b56d8ad(_jc_env *, struct _jc_javax_crypto_spec_DHPrivateKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_javax_crypto_spec_DHPrivateKeySpec$method$getP$612c6062f1779963(_jc_env *, struct _jc_javax_crypto_spec_DHPrivateKeySpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_javax_crypto_spec_DHPrivateKeySpec$method$getX$568a3b7b0d38db21(_jc_env *, struct _jc_javax_crypto_spec_DHPrivateKeySpec$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_DHPrivateKeySpec$method_info$getG$59cffd735b56d8ad;
extern _jc_method _jc_javax_crypto_spec_DHPrivateKeySpec$method_info$getP$612c6062f1779963;
extern _jc_method _jc_javax_crypto_spec_DHPrivateKeySpec$method_info$getX$568a3b7b0d38db21;

// Virtual methods structure
struct _jc_javax_crypto_spec_DHPrivateKeySpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getG$59cffd735b56d8ad)(_jc_env *, struct _jc_javax_crypto_spec_DHPrivateKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getP$612c6062f1779963)(_jc_env *, struct _jc_javax_crypto_spec_DHPrivateKeySpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getX$568a3b7b0d38db21)(_jc_env *, struct _jc_javax_crypto_spec_DHPrivateKeySpec$object *);
};

// Vtable
struct _jc_javax_crypto_spec_DHPrivateKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_DHPrivateKeySpec$vmethods	javax_crypto_spec_DHPrivateKeySpec;
};

// Vtype
struct _jc_javax_crypto_spec_DHPrivateKeySpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_DHPrivateKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_DHPrivateKeySpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*g;
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*x;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_DHPrivateKeySpec$refs {
    _jc_javax_crypto_spec_DHPrivateKeySpec$sub_refs	javax_crypto_spec_DHPrivateKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_DHPrivateKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_DHPrivateKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_DHPrivateKeySpec$sub_nonrefs	javax_crypto_spec_DHPrivateKeySpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_DHPrivateKeySpec$object {
	_jc_javax_crypto_spec_DHPrivateKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_DHPrivateKeySpec$vtype	*vtype;
	_jc_javax_crypto_spec_DHPrivateKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_DHPrivateKeySpec$vtype _jc_javax_crypto_spec_DHPrivateKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_DHPrivateKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_DHPrivateKeySpec$class_object;

#endif	/* _JC_javax_crypto_spec_DHPrivateKeySpec_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/spec/DHPrivateKeySpec.h <==
// public class javax.crypto.spec.DHPrivateKeySpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 35635a1ccf7cce67 javax_crypto_spec_DHPrivateKeySpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_DHPrivateKeySpec_H_
#define _JC_javax_crypto_spec_DHPrivateKeySpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_DHPrivateKeySpec$sub_refs	_jc_javax_crypto_spec_DHPrivateKeySpec$sub_refs;
typedef struct _jc_javax_crypto_spec_DHPrivateKeySpec$sub_nonrefs	_jc_javax_crypto_spec_DHPrivateKeySpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_DHPrivateKeySpec$refs	_jc_javax_crypto_spec_DHPrivateKeySpec$refs;
typedef struct _jc_javax_crypto_spec_DHPrivateKeySpec$nonrefs	_jc_javax_crypto_spec_DHPrivateKeySpec$nonrefs;
typedef struct _jc_javax_crypto_spec_DHPrivateKeySpec$object	_jc_javax_crypto_spec_DHPrivateKeySpec$object;

typedef const struct _jc_javax_crypto_spec_DHPrivateKeySpec$vmethods	_jc_javax_crypto_spec_DHPrivateKeySpec$vmethods;
typedef const struct _jc_javax_crypto_spec_DHPrivateKeySpec$vtable	_jc_javax_crypto_spec_DHPrivateKeySpec$vtable;
typedef const struct _jc_javax_crypto_spec_DHPrivateKeySpec$vtype	_jc_javax_crypto_spec_DHPrivateKeySpec$vtype;

// Constructors
extern void _jc_javax_crypto_spec_DHPrivateKeySpec$method$_init$6cf26681d886fcf0(_jc_env *, struct _jc_javax_crypto_spec_DHPrivateKeySpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_javax_crypto_spec_DHPrivateKeySpec$method$getG$59cffd735b56d8ad(_jc_env *, struct _jc_javax_crypto_spec_DHPrivateKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_javax_crypto_spec_DHPrivateKeySpec$method$getP$612c6062f1779963(_jc_env *, struct _jc_javax_crypto_spec_DHPrivateKeySpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_javax_crypto_spec_DHPrivateKeySpec$method$getX$568a3b7b0d38db21(_jc_env *, struct _jc_javax_crypto_spec_DHPrivateKeySpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_DHPrivateKeySpec$method_info$getG$59cffd735b56d8ad;
extern _jc_method _jc_javax_crypto_spec_DHPrivateKeySpec$method_info$getP$612c6062f1779963;
extern _jc_method _jc_javax_crypto_spec_DHPrivateKeySpec$method_info$getX$568a3b7b0d38db21;

// Virtual methods structure
struct _jc_javax_crypto_spec_DHPrivateKeySpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getG$59cffd735b56d8ad)(_jc_env *, struct _jc_javax_crypto_spec_DHPrivateKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getP$612c6062f1779963)(_jc_env *, struct _jc_javax_crypto_spec_DHPrivateKeySpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getX$568a3b7b0d38db21)(_jc_env *, struct _jc_javax_crypto_spec_DHPrivateKeySpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_crypto_spec_DHPrivateKeySpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_DHPrivateKeySpec$vmethods	javax_crypto_spec_DHPrivateKeySpec;
};

// Vtype
struct _jc_javax_crypto_spec_DHPrivateKeySpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_DHPrivateKeySpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_DHPrivateKeySpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*g;
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*x;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_DHPrivateKeySpec$refs {
    _jc_javax_crypto_spec_DHPrivateKeySpec$sub_refs	javax_crypto_spec_DHPrivateKeySpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_DHPrivateKeySpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_DHPrivateKeySpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_DHPrivateKeySpec$sub_nonrefs	javax_crypto_spec_DHPrivateKeySpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_DHPrivateKeySpec$object {
	_jc_javax_crypto_spec_DHPrivateKeySpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_DHPrivateKeySpec$vtype	*vtype;
	_jc_javax_crypto_spec_DHPrivateKeySpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_DHPrivateKeySpec$vtype _jc_javax_crypto_spec_DHPrivateKeySpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_DHPrivateKeySpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_DHPrivateKeySpec$class_object;

#endif	/* _JC_javax_crypto_spec_DHPrivateKeySpec_H_ */
